package	jp.co.sds_corp.hibiya.connector;

import java.util.Date;
import java.util.EventObject;

/**
* {@link IConnector}の接続状態に変化があったことを示すイベントです。
*/
public class ConnectionEvent extends EventObject
{
	private static final long serialVersionUID = 1L;
	private Object source;
	private Throwable exc;
	private String message;
	private Date when;

	/**
	* ConnectionEventを生成します。
	* @param	source		イベントの発生元
	* @param	exc			発生した例外
	* @param	message		メッセージ
	*/
	public ConnectionEvent( Object source, Throwable exc, String message ) {
		this( source );
		this.exc = exc;
		this.message = message;
		this.when = new Date();
	}

	/**
	* ConnectionEventを生成します。
	* @param	source		イベントの発生元
	*/
	public ConnectionEvent( Object source ) {
		super( source );
		this.source = source;
		this.when = new Date();
	}

	public Object getSource() {
		if ( source == null ) {
			return super.getSource();
		}
		return source;
	}

	/**
	* 発生した例外を返します。
	* @return	発生した例外
	*/
	public Throwable getException() {
		return exc;
	}
	/**
	* メッセージを返します。
	* @return	メッセージ
	*/
	public String getMessage() {
		return message;
	}
	/**
	* このイベントが発生した時点のタイムスタンプを返します。
	* @return	このイベントが発生した時点のタイムスタンプメッセージ
	*/
	public Date getWhen() {
		return when;
	}

	public String toString() {
		String ret = getClass().getName();
		ret += " source=[" + getSource() + "]";
		if ( exc != null ) {
			ret += " exc=" + exc;
		}
		return ret;
	}
}
