package	jp.co.sds_corp.hibiya.layout;

import jp.co.sds_corp.hibiya.server.CheckerChangeEvent;
import jp.co.sds_corp.hibiya.server.IChecker;
import jp.co.sds_corp.util.common.CmnDate;

/**
* 日付フィールドを編集するコンバータです。
*/
public class EventConverter implements IConverter
{
	private static final long serialVersionUID = 1L;
	public enum Type {
		/** タイプ：現在日時 */
		NOW,
		/** タイプ：前ステータス */
		OLD,
		/** タイプ：現ステータス */
		NEW,
		/** タイプ：例外 */
		EXCEPTION,
		/** タイプ：メッセージ */
		MESSAGE,
		/** タイプ：取得結果 */
		RESULT
	};

	Type	type;
	String pattern;

	/**
	* 指定されたタイプとフォーマット文字列でEventConverterを作成します。
	* @param	type	編集タイプ
	* @param	pattern	フォーマット文字列
	*/
	public EventConverter( Type type, String pattern ) {
		this.type = type;
		this.pattern = pattern;
	}

	/**
	* 文字列を編集して出力します。
	* @param	ev		編集元のデータ
	* @return	編集結果の文字列
	*/
	public String convert( CheckerChangeEvent ev ) {
		switch ( type ) {
		/** タイプ：現在日時 */
		case NOW:
			if ( pattern == null ) {
				pattern = "yyyy-MM-dd HH:mm:ss";
			}
			return new CmnDate().format( pattern );
		/** タイプ：前ステータス */
		case OLD:
			return String.valueOf( ev.getOldStatus() );
		/** タイプ：現ステータス */
		case NEW:
			return String.valueOf( ev.getNewStatus() );
		/** タイプ：例外 */
		case EXCEPTION:
			if ( ev.getException() == null ) {
				return null;
			}
			return ev.getException().toString();
		/** タイプ：メッセージ */
		case MESSAGE:
			return ev.getMessage();
		/** タイプ：レスポンス */
		case RESULT:
			IChecker chk = (IChecker )ev.getSource();
			Object res =  chk.getResult( pattern );
			if ( res == null ) {
				return null;
			}
			return res.toString();
		default:
			return "%" + pattern;
		}
	}
}
