package	jp.co.sds_corp.hibiya.server;

import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.config.UnspecifiedPropertyException;

/**
IDaemonの状況を監視します。
<BR>
XMLは以下の形式です。
<PRE>
&lt;Service name="Daemon1" class="jp.co.sds_corp.hibiya.server.DaemonChecker"&gt;
	&lt;Name&gt;192.168.0.1&lt;/Name&gt;
	&lt;Remote type="Socket"&gt;
		&lt;Host&gt;192.168.0.1&lt;/Host&gt;
		&lt;Port&gt;1090&lt;/Port&gt;
	&lt;/Remote&gt;
	&lt;Daemon&gt;DailyDaemon&lt;/Daemon&gt;
</PRE>

Action要素については、{@link jp.co.sds_corp.hibiya.action.IAction}
の説明を参照してください。
*/
public class DaemonChecker extends DaemonManagerChecker
{
	private static final long serialVersionUID = 1L;
	String	daemon;

	public DaemonChecker() {
		setType( "Daemon" );
	}

	/**
	* 設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );
		IConfiguration c = config.getChild( "Daemon" );
		if ( c == null ) {
			throw( new UnspecifiedPropertyException( "Daemon" ));
		}
		daemon = c.get();
	}

	/**
	* リモートコマンドを実行します。
	*/
	protected void command() throws Exception {
		Class<?>[] cls = { String.class };
		Object[] prm = { daemon };
		Object res = remote.execRemote( "getDaemonStatus", cls, prm );
		putResult( "DaemonStatus", res );
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
		config.addChild( "Daemon", daemon );
	}

	/**
	* このモニタの文字列表現を返します。
	* @return	このモニタの文字列表現
	*/
	public String toString() {
		String ret = super.toString();
		ret += "[" + daemon + "]";
		return ret;
	}

}
