package	jp.co.sds_corp.hibiya.server;

import jp.co.sds_corp.util.common.CmnDate;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.remote.IRemoteClient;
import jp.co.sds_corp.util.daemon.remote.RemoteFactory;

/**
IDaemonの状況を監視します。
<BR>
XMLは以下の形式です。
<PRE>
&lt;Service name="Daemon1" class="jp.co.sds_corp.hibiya.server.DaemonChecker"&gt;
	&lt;Name&gt;192.168.0.1&lt;/Name&gt;
	&lt;Remote type="Socket"&gt;
		&lt;Host&gt;192.168.0.1&lt;/Host&gt;
		&lt;Port&gt;1090&lt;/Port&gt;
	&lt;/Remote&gt;
</PRE>

Action要素については、{@link jp.co.sds_corp.hibiya.action.IAction}
の説明を参照してください。
*/
public class DaemonManagerChecker extends AbstractChecker
{
	private static final long serialVersionUID = 1L;
	IRemoteClient	remote;

	public DaemonManagerChecker() {
		setType( "DaemonManager" );
	}

	/**
	* 設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );

		IConfiguration c = config.getChild( "Remote" );
		if ( c == null ) {
			// 旧verとの互換性
			c = config.getChild( "Registry" );
			c.setAttribute( "type", "RMI" );
		}
		remote = RemoteFactory.createClient( c );
	}

	/**
	* 監視処理を実行します。
	*/
	public void check() {
		try {
			CmnDate startTime = new CmnDate();
			command();
			CmnDate endTime = new CmnDate();
			clearResult();
			setResponseTime( startTime, endTime );

			setCheckerStatus( IChecker.Status.OK );
		} catch ( Throwable ex ) {
			synchronized( this ) {
				clearResult();
				setException( ex );
				setCheckerStatus( IChecker.Status.NG );
			}
		}
	}

	/**
	* リモートコマンドを実行します。
	*/
	protected void command() throws Exception {
		Object res = remote.execRemote( "status" );
		putResult( "Status", res );
	}

	/**
	* IRemoteClientを設定します。
	* @param	var		設定するデータ
	*/
	public void setRemoteClient( IRemoteClient var ) {
		this.remote = var;
	}
	/**
	* IRemoteClientを取得します。
	* @return	IRemoteClient
	*/
	public IRemoteClient getRemoteClient() {
		return remote;
	}


	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
		IConfiguration c = config.addChild( "Remote" );
		remote.saveConfig( c );
	}

	/**
	* このモニタの文字列表現を返します。
	* @return	このモニタの文字列表現
	*/
	public String toString() {
		String ret = super.toString();
		if ( remote != null ) {
			ret += "[" + remote.toString()  + "]";
 		}
		return ret;
	}

}
